/******************** (C) COPYRIGHT 2008 STMicroelectronics ********************
* File Name          : main.c
* Author             : MCD Application Team
* Version            : V2.0.1
* Date               : 06/13/2008
* Description        : Main program body.
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/

/* LED*/
#define RCC_GPIO_LED                    RCC_APB2Periph_GPIOF    /*LED GPIO CLOCK*/
#define LEDn                            4                       /*LED NUMBER*/
#define GPIO_LED                        GPIOF                   /*LED GPIO GROUP*/

#define DS1_PIN                         GPIO_Pin_6              /*DS1 GPIO PIN*/
#define DS2_PIN                         GPIO_Pin_7				/*DS2 GPIO PIN*/
#define DS3_PIN                         GPIO_Pin_8  			/*DS3 GPIO PIN*/
#define DS4_PIN                         GPIO_Pin_9				/*DS4 GPIO PIN*/

/* Private macro -------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
GPIO_InitTypeDef GPIO_InitStructure;
ErrorStatus HSEStartUpStatus;
u8 count=0;

/* Private function prototypes -----------------------------------------------*/
void RCC_Configuration(void);
void NVIC_Configuration(void);
void Delay(vu32 nCount);
void Turn_On_LED(u8 LED_NUM);

/* Private functions ---------------------------------------------------------*/

/*******************************************************************************
* Function Name  : main
* Description    : Main program.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
int main(void)
{

  	/* CONFIG LED GPIO PIN MODE*/
  	RCC_APB2PeriphClockCmd(RCC_GPIO_LED, ENABLE); /*ENABLE LED GPIO CLOCK*/

  	GPIO_InitStructure.GPIO_Pin = DS1_PIN|DS2_PIN|DS3_PIN|DS4_PIN; 	 /*ENABLE LED GPIO PIN*/
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;	   /*SET LED GPIO MODE*/
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;		 /*SET LED GPIO CLOCK*/
  
  	GPIO_Init(GPIO_LED, &GPIO_InitStructure);  /*INITIALIZE LED GPIO*/
  	GPIO_SetBits(GPIO_LED,DS1_PIN|DS2_PIN|DS3_PIN|DS4_PIN);/*CLOSE ALL LED*/

  	while(1)
  	{	
		GPIO_SetBits(GPIO_LED,DS1_PIN|DS2_PIN|DS3_PIN|DS4_PIN);/*CLOSE ALL LED*/
		Turn_On_LED(count%4);	/*OPEN ONE LED*/	
		count++;
		Delay(0x2FFFFF);
  	}
  
}

/*OPEN ONE LED*/
void Turn_On_LED(u8 LED_NUM)
{
	switch(LED_NUM)
	{
        case 0:
          GPIO_ResetBits(GPIO_LED,DS1_PIN);  /*OPEN DS1*/
          break;
        case 1:
          GPIO_ResetBits(GPIO_LED,DS2_PIN);  /*OPEN DS2*/
          break;
        case 2:
          GPIO_ResetBits(GPIO_LED,DS3_PIN);  /*OPEN DS3*/
          break;
        case 3:
          GPIO_ResetBits(GPIO_LED,DS4_PIN);  /*OPEN DS4*/
          break;          
        default:
		  GPIO_ResetBits(GPIO_LED,DS1_PIN|DS2_PIN|DS3_PIN|DS4_PIN); /*OPEN ALL LED*/
          break;
	}
}


/*******************************************************************************
* Function Name  : Delay
* Description    : Inserts a delay time.
* Input          : nCount: specifies the delay time length.
* Output         : None
* Return         : None
*******************************************************************************/
void Delay(vu32 nCount)
{
  for(; nCount != 0; nCount--);
}



/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
