/**
  ******************************************************************************
  * @file    USART/Printf/main.c 
  * @author  MCD Application Team
  * @version V3.3.0
  * @date    04/16/2010
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 STMicroelectronics</center></h2>
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
#include "stm32_eval.h"
#include <stdio.h>

/** @addtogroup STM32F10x_StdPeriph_Examples
  * @{
  */

/** @addtogroup USART_Printf
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/*IIILEDض*/
#define RCC_GPIO_LED                    RCC_APB2Periph_GPIOF    /*LEDʹõGPIOʱ*/
#define LEDn                            4                       /*IIILED*/
#define GPIO_LED                        GPIOF                   /*IIILEDʹõGPIO*/

#define DS1_PIN                         GPIO_Pin_6              /*DS1ʹõGPIOܽ*/
#define DS2_PIN                         GPIO_Pin_7				/*DS2ʹõGPIOܽ*/
#define DS3_PIN                         GPIO_Pin_8  			/*DS3ʹõGPIOܽ*/
#define DS4_PIN                         GPIO_Pin_9				/*DS4ʹõGPIOܽ*/


/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
USART_InitTypeDef USART_InitStructure;

/* Private function prototypes -----------------------------------------------*/

#ifdef __GNUC__
  /* With GCC/RAISONANCE, small printf (option LD Linker->Libraries->Small printf
     set to 'Yes') calls __io_putchar() */
  #define PUTCHAR_PROTOTYPE int __io_putchar(int ch)
#else
  #define PUTCHAR_PROTOTYPE int fputc(int ch, FILE *f)
#endif /* __GNUC__ */
  
/* Private functions ---------------------------------------------------------*/
/*******************************************************************************
* Function Name  : Delay
* Description    : Inserts a delay time.
* Input          : nCount: specifies the delay time length.
* Output         : None
* Return         : None
*******************************************************************************/
void Delay(vu32 nCount)
{
  for(; nCount != 0; nCount--);
}

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void)
{
  /*LEDܽųʼ*/
  GPIO_InitTypeDef GPIO_InitStructure;
  RCC_APB2PeriphClockCmd(RCC_GPIO_LED, ENABLE);

  GPIO_InitStructure.GPIO_Pin = DS1_PIN|DS2_PIN|DS3_PIN|DS4_PIN ;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIO_LED, &GPIO_InitStructure);
  
  GPIO_SetBits(GPIO_LED, DS1_PIN|DS2_PIN|DS3_PIN|DS4_PIN);	/*رLED*/      
   
  /* USARTx configured as follow:
        - BaudRate = 115200 baud  
        - Word Length = 8 Bits
        - One Stop Bit
        - No parity
        - Hardware flow control disabled (RTS and CTS signals)
        - Receive and transmit enabled
  */
  /*ڲ*/
  USART_InitStructure.USART_BaudRate = 115200;                 /*òΪ115200*/
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;  /*λΪ8λ*/
  USART_InitStructure.USART_StopBits = USART_StopBits_1;       /*ֹͣλΪ1λ*/
  USART_InitStructure.USART_Parity = USART_Parity_No;          /*żУ*/    
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None; /*ûӲ*/
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;      /**/
  /*ɴCOM1ʱáGPIOãʼʹ*/

  STM_EVAL_COMInit(COM1, &USART_InitStructure);


  printf("\n\r---------------------------------------------\n ");
  printf("\n\rWWW.CSUN.CO.JP\n ");
  printf("\n\rCOM1 test program\n");

  while (1)
  {
  		GPIO_ResetBits(GPIO_LED, DS1_PIN);
		Delay(0x3FFFFF);
  		GPIO_SetBits(GPIO_LED, DS1_PIN);
		Delay(0x3FFFFF); 
		printf("\n\rCOM1 test\n");	   
  }
}

/**
  * @brief  Retargets the C library printf function to the USART.
  * @param  None
  * @retval None
  */
PUTCHAR_PROTOTYPE
{
  /* Place your implementation of fputc here */
  /* e.g. write a character to the USART */
  USART_SendData(EVAL_COM1, (uint8_t) ch); /*һַ*/ 

  /* Loop until the end of transmission */
  while (USART_GetFlagStatus(EVAL_COM1, USART_FLAG_TC) == RESET)/*ȴ*/
  {
  
  }
  return ch;
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */ 

/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2010 STMicroelectronics *****END OF FILE****/
