/**
  ******************************************************************************
  * @file    USART/Printf/main.c 
  * @author  MCD Application Team
  * @version V3.3.0
  * @date    04/16/2010
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 STMicroelectronics</center></h2>
  */ 


/* Includes ------------------------------------------------------------------*/
#include "i2c_ee.h"

#include "stm32f10x_usart.h"
#include "platform_config.h"
#include "misc.h"
#include "stm32f10x.h"
#include "math.h"

#include "stdlib.h"
#include "stdio.h"
#include <string.h>
#include "Tea5756.h"

#define TxBufferSize1   (countof(TxBuffer1) - 1)
#define RxBufferSize1   (countof(TxBuffer1) - 1)

/* Private typedef -----------------------------------------------------------*/
typedef enum {FAILED = 0, PASSED = !FAILED} TestStatus;
/* Private define ------------------------------------------------------------*/
#define Tea5767_WriteAddress1    0xc0
#define Tea5767_ReadAddress1     0xc1

#define BufferSize1             (countof(Tx1_Buffer)-1)
#define BufferSize2             (countof(Tx2_Buffer)-1)
#define EEPROM_WriteAddress2    (EEPROM_WriteAddress1 + BufferSize1)
#define EEPROM_ReadAddress2     (EEPROM_ReadAddress1 + BufferSize1)

#define RCC_GPIO_LED    RCC_APB2Periph_GPIOF
/* Private macro -------------------------------------------------------------*/
#define countof(a) (sizeof(a) / sizeof(*(a)))

char TxBuffer1[] = "STM32 TEA5767 tuner test";
char RxBuffer1[RxBufferSize1],rec_f;
__IO uint8_t TxCounter1 = 0x00;
__IO uint8_t RxCounter1 = 0x00; 
uint8_t NbrOfDataToTransfer1 = TxBufferSize1;
uint8_t NbrOfDataToRead1 = RxBufferSize1;
USART_InitTypeDef USART_InitStructure;
USART_ClockInitTypeDef USART_ClockInitStruct;

int GetKey (void) ;
int SendChar (int ch) ;
/* Private variables ---------------------------------------------------------*/
USART_InitTypeDef USART_InitStructure;
uint8_t Tx1_Buffer[] = {0XF0,0X2C,0XD0,0X12,0X40};
uint8_t Rx1_Buffer[] = {0XF0,0X2C,0XD0,0X12,0X40};
uint8_t Rx2_Buffer[] = {0X11,0X22,0X33,0X44,0X55};
uint8_t Tx2_Buffer[] = {0X00,0Xc0,0xe0,0X41,0X6e,0X7e};


unsigned long FM_FREQ=98800000;
unsigned long FM_PLL;
unsigned char PLL_HIGH=0;
unsigned char PLL_LOW=0;
unsigned char len=0; 

volatile TestStatus TransferStatus1 = FAILED, TransferStatus2 = FAILED;

/* Private function prototypes -----------------------------------------------*/
void RCC_Configuration(void);
void SetPLL(void);

void Delay(__IO uint32_t nCount);
void USART_OUT(USART_TypeDef* USARTx, uint8_t *Data,uint16_t Len);
void NVIC_Configuration(void);
void GPIO_Configuration(void);
extern bool I2C_ReadByte(u8* pBuffer,   u8 length,   u8 DeviceAddress);

extern void GPIO_Configuration(void);

TestStatus Buffercmp(uint8_t* pBuffer1, uint8_t* pBuffer2, uint16_t BufferLength);

unsigned char ch2=0;

  
/* Private functions ---------------------------------------------------------*/


/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void)
{
  
  float a=0;
  unsigned long fm_ch[50];
  unsigned char ch1=0;
  unsigned char i =0;

  /* System clocks configuration ---------------------------------------------*/
  RCC_Configuration();
  NVIC_Configuration();
  /* Initialize the I2C EEPROM driver ----------------------------------------*/
  	
  GPIO_Configuration();

  
  /*ڳʼ*/     
  /* USARTx configured as follow:
        - BaudRate = 115200 baud  
        - Word Length = 8 Bits
        - One Stop Bit
        - No parity
        - Hardware flow control disabled (RTS and CTS signals)
        - Receive and transmit enabled
  */
  USART_InitStructure.USART_BaudRate = 115200;
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_No;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;

    /* Configure USART1 */
  USART_Init(USART1, &USART_InitStructure);

  /* Enable USART1 Receive and Transmit interrupts */
  USART_ITConfig(USART1, USART_IT_RXNE, ENABLE);
  //USART_ITConfig(USART1, USART_IT_TXE, ENABLE);

  /* Enable the USART1 */
  USART_Cmd(USART1, ENABLE);  
  Delay(0xafffff);



  /* Output a message on Hyperterminal using printf function */
  printf("\n\r---------------------------------------------\n ");
  printf("\n\rSTM32 TEA5767 Tuner test\n");
  printf("\r\n");  
  printf("\r\n H(h)---help  \n\r S(s)---search program\n");
  printf("\r\n D(d)---display program  \n\r xxP(xxp)---play the selected program(ex. 10P) \n");
  printf("\r\n xx.xM(xx.xm)---select band(ex. 100.8M)      \n");
  printf("\r\n"); 


  if(FALSE == I2C_Write(Tx1_Buffer, Tea5767_WriteAddress1, 5)) 
  {
	    GPIO_ResetBits(GPIOF, GPIO_Pin_6);
  }

  SetPLL();

  while (1)
  {	
    //printf(".");
  	if(rec_f!=0){
		
		if(rec_f==1){                   //input frequence
			a=atof(TxBuffer1);
			FM_FREQ=a*1000000;
			SetPLL();
			printf("\r current FM frequence:   %g\n MHz \n",a); 
		}
		else if(rec_f==2){                   //search

			printf("\n Search FM program! \n");
			Tx1_Buffer[0] = 0XF0; 

			FM_FREQ=87500000;
			FM_FREQ=FM_FREQ+100000;				
		  	SetPLL(); 
			Delay(0x6fffff);
//			I2C_ReadByte(Rx1_Buffer,5,Tea5767_ReadAddress1);
			I2C_ReadByte(Rx2_Buffer,5,Tea5767_ReadAddress1);
			printf("the ReadByte is:\n");

			for(i = 0; i <5 ; i++)
			{

				printf("0x%X,\t",Rx2_Buffer[i]);
			}
			printf("\n");
			
			ch2=0;
		 	while(1){
		    //IF<51  IF>55  LEVEL<9
				fm_pub:;
				FM_FREQ=FM_FREQ+100000;			
		  		if(FM_FREQ>108000000){FM_FREQ=98800000; break;}  
				SetPLL(); 
				Delay(0x0fffff);
				I2C_ReadByte(Rx1_Buffer,5,Tea5767_ReadAddress1);				
				a=FM_FREQ;
				a=a/1000000;		
				//if((Rx1_Buffer[0]&0x3f)!=(Tx1_Buffer[0]&0x3f)||(Rx1_Buffer[1]!=Tx1_Buffer[1])||Rx1_Buffer[2]<51||Rx1_Buffer[2]>=55||(Rx1_Buffer[3]>>4)<9){	
				if((Rx1_Buffer[0]&0x3f)!=(Tx1_Buffer[0]&0x3f)||(Rx1_Buffer[1]!=Tx1_Buffer[1])||(Rx1_Buffer[1]&0x80!=0x80)||Rx1_Buffer[2]<50||Rx1_Buffer[2]>=56||(Rx1_Buffer[3]>>4)<7||(Rx1_Buffer[3]>>4)>14){
					printf("\r\nCurrent FM frequence:   %g MHz",a); 
				}
				else {					
					printf("\r\nCurrent FM frequence:   %g MHz     have signal!!!    %u  %u",a, Rx1_Buffer[2],Rx1_Buffer[3]>>4);
					fm_ch[ch2]= FM_FREQ; 					
					ch2++;
					goto fm_pub;
				}
				
				
			}
			if(FM_FREQ!=98800000) goto fm_pub;
			printf("\r\n valid FM freq. number:   %u \n",ch2); 
			ch1=ch2;
			while(ch1--){
				a=fm_ch[ch1];
				a=a/1000000;	
				printf("\r\n %u  FM freq.: %g  MHz \n",ch1,a); 
			}				
		}
		else if(rec_f==3){                   //display valid freq.
			printf("\r\n valid FM freq. number:   %u \n",ch2); 
			ch1=ch2;
			while(ch1--){
				a=fm_ch[ch1];
				a=a/1000000;	
				printf("\r\n %u  FM freq.: %g  MHz \n",ch1,a); 
			}				
		}
		else if(rec_f==4){                   //display valid freq.
			ch1=atoi(TxBuffer1);
			FM_FREQ=fm_ch[ch1];
			a=fm_ch[ch1];
			a=a/1000000;
			printf("\r\n current FM freq.:   %g MHz \n",a); 
		}
	    else if(rec_f==5){                   //ʾЧƵ
			printf("\r\n STM32 TEA5767 DEMO \n");
  			printf("\r\n");
  			printf("\r\n");
  			printf("\r\n H(h)---help                   S(s)---search program  \n");
  			printf("\r\n D(d)---display program        xxP(xxp)---play selected program(ex. 12P) \n");
  			printf("\r\n xx.xM(xx.xm)---select band(ex. 98.8M)      \n");
  			printf("\r\n");
  			printf("\r\n");
		}
		rec_f=0;
		SetPLL();
	}
  }

}

void USART_OUT(USART_TypeDef* USARTx, uint8_t *Data,uint16_t Len)
{ 
	uint16_t i;
	for(i=0; i<Len-2; i++){
		USART_SendData(USARTx, Data[i]);
		while(USART_GetFlagStatus(USARTx, USART_FLAG_TC)==RESET);
	}
	USART_SendData(USARTx, 0x0d);
	while(USART_GetFlagStatus(USARTx, USART_FLAG_TC)==RESET);
	USART_SendData(USARTx, 0x0a);
	while(USART_GetFlagStatus(USARTx, USART_FLAG_TC)==RESET);

}

void Delay(__IO uint32_t nCount)
{
  for(; nCount != 0; nCount--);
}

void SetPLL(void)
{
   //FM_PLL=(unsigned long)((4000*(FM_FREQ/1000+225))/32768); 	//Уֵ̣
   FM_PLL=(unsigned long)((4000*(FM_FREQ/1000+225))/32768); 	//Уֵ̣
   if(rec_f==2) PLL_HIGH=(unsigned char)(((FM_PLL >> 8)&0X3f)|0xc0);	 //PLLֵֽ
   else PLL_HIGH=(unsigned char)((FM_PLL >> 8)&0X3f);	 //PLLֵֽ
   //Tx1_Buffer[0]=(Tx1_Buffer[0]&0XC0)|PLL_HIGH;		 //I2Cһֵֽ
   Tx1_Buffer[0]=PLL_HIGH;		 //I2Cһֵֽ
   PLL_LOW=(unsigned char)FM_PLL;			      		 //PLLֵֽ
   Tx1_Buffer[1]= PLL_LOW;						 //I2Cڶֵֽ
   I2C_Write(Tx1_Buffer, Tea5767_WriteAddress1, 5); 
}






void NVIC_Configuration(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;

/* Set the Vector Table base address at 0x08000000 */
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0000);

  /* Configure the NVIC Preemption Priority Bits */  
  NVIC_PriorityGroupConfig(NVIC_PriorityGroup_0);
  
  /* Enable the USART1 Interrupt */
  NVIC_InitStructure.NVIC_IRQChannel = USART1_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);

  
}
/**
  * @brief  Configures the different system clocks.
  * @param  None
  * @retval : None
  */
void RCC_Configuration(void)
{
  /* Setup the microcontroller system. Initialize the Embedded Flash Interface,  
     initialize the PLL and update the SystemFrequency variable. */
  SystemInit();

/* Enable peripheral clocks --------------------------------------------------*/
  /* GPIOB Periph clock enable */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_USART1 | RCC_APB2Periph_AFIO, ENABLE);
  
  /* I2C1 Periph clock enable */
  //RCC_APB1PeriphClockCmd(RCC_APB1Periph_I2C1, ENABLE);
}

int SendChar (int ch)  {                /* Write character to Serial Port     */

  USART_SendData(USART1, (unsigned char) ch);
  while (!(USART1->SR & USART_FLAG_TXE));
  return (ch);
}

/**
  * @brief  Retargets the C library printf function to the USART.
  * @param  None
  * @retval None
  */

//PUTCHAR_PROTOTYPE
//{
  /* Place your implementation of fputc here */
  /* e.g. write a character to the USART */
  //USART_SendData(EVAL_COM1, (uint8_t) ch);

  /* Loop until the end of transmission */
  //while (USART_GetFlagStatus(EVAL_COM1, USART_FLAG_TC) == RESET)
  //{
  //}

//  return ch;
//}



/*******************************************************************************
* Function Name  : fputc
* Description    : Retargets the C library printf function to the USART.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
int fputc(int ch, FILE *f)
{
  /* Place your implementation of fputc here */
  /* e.g. write a character to the USART */
  USART_SendData(USART1, (u8) ch);

  /* Loop until the end of transmission */
  while(USART_GetFlagStatus(USART1, USART_FLAG_TC) == RESET)
  {
  }

  return ch;
}

/**
  * @brief  Compares two buffers.
  * @param pBuffer1, pBuffer2: buffers to be compared.
  * @param BufferLength: buffer's length
  * @retval : PASSED: pBuffer1 identical to pBuffer2
  *   FAILED: pBuffer1 differs from pBuffer2
  */
TestStatus Buffercmp(uint8_t* pBuffer1, uint8_t* pBuffer2, uint16_t BufferLength)
{
  while(BufferLength--)
  {
    if(*pBuffer1 != *pBuffer2)
    {
      return FAILED;
    }
    
    pBuffer1++;
    pBuffer2++;
  }

  return PASSED;  
}
/**
  * @brief  Configure the used I/O ports pin
  * @param  None
  * @retval : None
  */
void GPIO_Configuration(void)
{
  GPIO_InitTypeDef  GPIO_InitStructure; 
  RCC_APB2PeriphClockCmd( RCC_APB2Periph_USART1 |RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB |
                         RCC_APB2Periph_GPIOC | RCC_APB2Periph_GPIOD |
                         RCC_APB2Periph_GPIOE|RCC_APB2Periph_GPIOF, ENABLE);

  /* Configure I2C1 pins: SCL and SDA */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6 | GPIO_Pin_7;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode =  GPIO_Mode_Out_OD;
  GPIO_Init(GPIOB, &GPIO_InitStructure);

  /*LEDƳʼ*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6|GPIO_Pin_7|GPIO_Pin_8|GPIO_Pin_9;				     //LED1
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOF, &GPIO_InitStructure);					 

  /*ڹܽųʼ*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9;	         //USART1 TX
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;    //
  GPIO_Init(GPIOA, &GPIO_InitStructure);		    //A˿ 

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_10;	         //USART1 RX
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;   //ÿ©
  GPIO_Init(GPIOA, &GPIO_InitStructure);		         //A˿ 
}


/**
  * @}
  */ 

/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/


#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */ 

/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2010 STMicroelectronics *****END OF FILE****/
