//new-redbull
#include "NRF24l01.h"
#include "delay.h"
#include "spi.h"



//NRF24L01 driver 

	 
const u8 TX_ADDRESS[TX_ADR_WIDTH]={0x34,0x43,0x10,0x10,0x01}; //transmit address
const u8 RX_ADDRESS[RX_ADR_WIDTH]={0x34,0x43,0x10,0x10,0x01}; //receive address							    
//initialize 24L01 IO
void NRF24L01_Init(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;
	RCC_APB2PeriphClockCmd(RCC_NRF24L01_CE, ENABLE);           //enable GPIO clock
    GPIO_InitStructure.GPIO_Pin = NRF24L01_CE;              //NRF24L01 ce
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;           
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(GPIO_NRF24L01_CE, &GPIO_InitStructure);

	RCC_APB2PeriphClockCmd(RCC_NRF24L01_CSN, ENABLE);          //enable GPIO clock
    GPIO_InitStructure.GPIO_Pin = NRF24L01_CSN;      
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;           
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(GPIO_NRF24L01_CSN, &GPIO_InitStructure);
	
	Set_NRF24L01_CE;                                           //pull up when initialize
    Set_NRF24L01_CSN;                                   //pull up when initialize

    //NRF2401IRQ
	GPIO_InitStructure.GPIO_Pin = NRF24L01_IRQ;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU  ;     
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(GPIO_NRF24L01_IRQ, &GPIO_InitStructure);
	GPIO_SetBits(GPIO_NRF24L01_IRQ,NRF24L01_IRQ);

	SPI2_Init();                                       //initialize SPI
	Clr_NRF24L01_CE; 	                               //enable 24L01
	Set_NRF24L01_CSN;                                  //SPI cs cancle
}
//check NRF24L01
u8 NRF24L01_Check(void)
{
	u8 buf[5]={0XA5,0XA5,0XA5,0XA5,0XA5};
	u8 buf1[5];
	u8 i;   	 
	NRF24L01_Write_Buf(SPI_WRITE_REG+TX_ADDR,buf,5);//write 5 byte	
	NRF24L01_Read_Buf(TX_ADDR,buf1,5);              //reda  	
	for(i=0;i<5;i++)if(buf1[i]!=0XA5)break;					   
	if(i!=5)return 1;                               //NRF24L01 is not exist	
	return 0;		                                //NRF24L01 is exist
}	 	 
//write register by SPI
u8 NRF24L01_Write_Reg(u8 regaddr,u8 data)
{
	u8 status;	
    Clr_NRF24L01_CSN;                    //enable SPI
  	status =SPI2_ReadWriteByte(regaddr); //send register address 
  	SPI2_ReadWriteByte(data);            //write data
  	Set_NRF24L01_CSN;                    //disable SPI	   
  	return(status);       		         //return result
}
//read register by SPI,regaddr:register address
u8 NRF24L01_Read_Reg(u8 regaddr)
{
	u8 reg_val;	    
 	Clr_NRF24L01_CSN;                //enable SPI		
  	SPI2_ReadWriteByte(regaddr);     //send register address 
  	reg_val=SPI2_ReadWriteByte(0XFF);//read data
  	Set_NRF24L01_CSN;                //disable SPI	    
  	return(reg_val);                 //return result
}	
u8 NRF24L01_Read_Buf(u8 regaddr,u8 *pBuf,u8 datalen)
{
	u8 status,u8_ctr;	       
  	Clr_NRF24L01_CSN;                     //enable SPI
  	status=SPI2_ReadWriteByte(regaddr);   //send register address and read status  	   
 	for(u8_ctr=0;u8_ctr<datalen;u8_ctr++)pBuf[u8_ctr]=SPI2_ReadWriteByte(0XFF);//read data
  	Set_NRF24L01_CSN;                     //disable SPI	 
  	return status;                        //return result
}
u8 NRF24L01_Write_Buf(u8 regaddr, u8 *pBuf, u8 datalen)
{
	u8 status,u8_ctr;	    
 	Clr_NRF24L01_CSN;                                    //enable SPI
  	status = SPI2_ReadWriteByte(regaddr);                //send register address and read status 
  	for(u8_ctr=0; u8_ctr<datalen; u8_ctr++)SPI2_ReadWriteByte(*pBuf++); //write data
  	Set_NRF24L01_CSN;                                    //disable SPI
  	return status;                                       //return result
}				   
u8 NRF24L01_TxPacket(u8 *txbuf)
{
	u8 state;   
	Clr_NRF24L01_CE;
  	NRF24L01_Write_Buf(WR_TX_PLOAD,txbuf,TX_PLOAD_WIDTH);//write data to TX BUF  32 byte
 	Set_NRF24L01_CE;                                     //	   
	while(READ_NRF24L01_IRQ!=0);                             
	state=NRF24L01_Read_Reg(STATUS);                     //read status	   
	NRF24L01_Write_Reg(SPI_WRITE_REG+STATUS,state);      //clear TX_DS or MAX_RT
	if(state&MAX_TX)                                     //
	{
		NRF24L01_Write_Reg(FLUSH_TX,0xff);               //clear TX FIFO
		return MAX_TX; 
	}
	if(state&TX_OK)                                      //send over
	{
		return TX_OK;
	}
	return 0xff;                                         //error by other reason
}
u8 NRF24L01_RxPacket(u8 *rxbuf)
{
	u8 state;		    							      
	state=NRF24L01_Read_Reg(STATUS);                //read status    	 
	NRF24L01_Write_Reg(SPI_WRITE_REG+STATUS,state); //clear TX_DS or MAX_RT
	if(state&RX_OK)                                 //receive data
	{
		NRF24L01_Read_Buf(RD_RX_PLOAD,rxbuf,RX_PLOAD_WIDTH);//read data
		NRF24L01_Write_Reg(FLUSH_RX,0xff);          //clear RX FIFO 
		return 0; 
	}	   
	return 1;                                      //no data
}

//set NRF24L01 to RX mode
//set RX address, RX data length, RF channel, band and LNA HCURR		   
void RX_Mode(void)
{
	Clr_NRF24L01_CE;	  
  	NRF24L01_Write_Buf(SPI_WRITE_REG+RX_ADDR_P0,(u8*)RX_ADDRESS,RX_ADR_WIDTH);//дRXڵַ
	  
  	NRF24L01_Write_Reg(SPI_WRITE_REG+EN_AA,0x01);    //enable channel 0    
  	NRF24L01_Write_Reg(SPI_WRITE_REG+EN_RXADDR,0x01);//enable channel 0 address  	 
  	NRF24L01_Write_Reg(SPI_WRITE_REG+RF_CH,40);	     //set RF band		  
  	NRF24L01_Write_Reg(SPI_WRITE_REG+RX_PW_P0,RX_PLOAD_WIDTH);//set channel 0 data length 	    
  	NRF24L01_Write_Reg(SPI_WRITE_REG+RF_SETUP,0x0f); 
  	NRF24L01_Write_Reg(SPI_WRITE_REG+CONFIG, 0x0f);  //set parameter,PWR_UP,EN_CRC,16BIT_CRC,receive mode 
  	Set_NRF24L01_CE;                                //set CE to high, start to receiving data
}						 
//set NRF24L01 to TX mode
//set TX address,TX data length,etc.
//enable PWR_UP,CRC
//CEߺ,RXģʽ,Խ		   
//CE is high and longer than 10us,start to send data.	 
void TX_Mode(void)
{														 
	Clr_NRF24L01_CE;	    
  	NRF24L01_Write_Buf(SPI_WRITE_REG+TX_ADDR,(u8*)TX_ADDRESS,TX_ADR_WIDTH);    
  	NRF24L01_Write_Buf(SPI_WRITE_REG+RX_ADDR_P0,(u8*)RX_ADDRESS,RX_ADR_WIDTH);   

  	NRF24L01_Write_Reg(SPI_WRITE_REG+EN_AA,0x01);     
  	NRF24L01_Write_Reg(SPI_WRITE_REG+EN_RXADDR,0x01);   
  	NRF24L01_Write_Reg(SPI_WRITE_REG+SETUP_RETR,0x1a);
  	NRF24L01_Write_Reg(SPI_WRITE_REG+RF_CH,40);      
  	NRF24L01_Write_Reg(SPI_WRITE_REG+RF_SETUP,0x0f);   
  	NRF24L01_Write_Reg(SPI_WRITE_REG+CONFIG,0x0e);    
	Set_NRF24L01_CE;                                  
}		  


