/**
  ******************************************************************************
  * @file    USART/Printf/main.c 
  * @author  MCD Application Team
  * @version V3.3.0
  * @date    04/16/2010
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 STMicroelectronics</center></h2>
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
#include "stm32_eval.h"
#include <stdio.h>
#include "ili9320.h"
#include "ili9320_api.h"
#include <stdio.h>
#include "ARMJISHU_TouchScreen_ADS7843.h"
#include "picture.h"
/** @addtogroup STM32F10x_StdPeriph_Examples
  * @{
  */

/** @addtogroup USART_Printf
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define BmpHeadSize (54)
#define RCC_GPIO_LED    RCC_APB2Periph_GPIOF
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
USART_InitTypeDef USART_InitStructure;
GPIO_InitTypeDef GPIO_InitStructure;
/* Private function prototypes -----------------------------------------------*/

#ifdef __GNUC__
  /* With GCC/RAISONANCE, small printf (option LD Linker->Libraries->Small printf
     set to 'Yes') calls __io_putchar() */
  #define PUTCHAR_PROTOTYPE int __io_putchar(int ch)
#else
  #define PUTCHAR_PROTOTYPE int fputc(int ch, FILE *f)
#endif /* __GNUC__ */
  
/* Private functions ---------------------------------------------------------*/


static void Delay_ARMJISHU(__IO uint32_t nCount)
{
  for (; nCount != 0; nCount--)
  {
      if(GPIO_ADS7843_INT_VALID)
      {
        ARMJISHU_TouchScreen_ADS7843();
      }	
  }
}


void ili9320_PutStr_16x24(u16 StartX, u16 StartY, u8 *str, u16 len, u16 charColor, u16 bkColor)
{
  u16 i;
  u8 *pstr = str;
      
      for (i=0 ;i<len;i++)
      {
        //ili9320_PutChar((x+8*i),y,*str++,charColor,bkColor);
        ili9320_PutChar_16x24((StartX+16*i),StartY,*pstr++,charColor,bkColor);
      }
      
}

void ili9320_PutStr_16x24_Center(u16 StartY, u8 *str, u16 len, u16 charColor, u16 bkColor)
{
  u16 StartX;

  StartX = (320 - 16*len)/2;
      
      ili9320_PutStr_16x24(StartX,StartY, str, len, charColor, bkColor);
}

void ili9320_ColorScreen(void)
{
  u16 i, j, k, Color;
  
  for(i=0,k=0; i<320; i++)
  {
      if(!(k & 0x3F))
      {
          k= k + 19;
      }
      else
      {
          k++;
      }
      j = (k>>1) & 0x1F;
      switch(k>>6)
      {
         case 0:
              Color = (j<<11) ;
              break;
         case 1:
              Color = (j<<11) | (j<<6) ;
              break;
         case 2:
              Color =  (j<<6) ;
              break;
         case 3:
              Color =  (j<<6) | j;
              break;
         case 4:
              Color = j;              
              break;
         case 5:
              Color = (j<<11) | j;
              break;
         default:
              Color = (j<<11) |(j<<6) | j;
      }
      GUI_Line(i, 0, i, 239, Color);
  }
}

void ili9320_GreyScreen(void)
{
  u16 i, j, Color;
  
  for(i=0; i<320; i++)
  {
      j =  i /10;
      Color = (j<<11) | (j<<6) | j;       
      GUI_Line(i, 0, i, 239, Color);
  }
}

void DrawPicture_Center(u16 *PictureAddr)  
{
    PictureWidth = (picture[0x13] << 8) | picture[0x12];
    PictureHeight  = (picture[0x17] << 8) | picture[0x16];
    
    printf("\n\r PictureWidth is %d  0x%X ", PictureWidth, PictureWidth);
    printf("\n\r PictureHeight is %d  0x%X ", PictureHeight, PictureHeight);
    
    ili9320_Clear(Blue); 
    ili9320_DrawPicture(0, (240-PictureWidth+1)/2, 320-1, ((240+PictureWidth+1)/2)-1, (u16 *)(picture + BmpHeadSize));
}


/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void)
{
  /*!< At this stage the microcontroller clock setting is already configured, 
       this is done through SystemInit() function which is called from startup
       file (startup_stm32f10x_xx.s) before to branch to application main.
       To reconfigure the default setting of SystemInit() function, refer to
       system_stm32f10x.c file
     */     
  u16 i, len, c2len;
  u16 x;
  u16 y;
  u8 c[] = "www.armjishu.com";
  u8 c2[] = "MP3 LCD 320X240";
  u8 *str;
  u16 charColor;
  u16 bkColor;
  
  len = sizeof(c)-1;
  c2len = sizeof(c2)-1;


  RCC_APB2PeriphClockCmd(RCC_GPIO_LED, ENABLE);

  GPIO_InitStructure.GPIO_Pin = LED1_PIN|LED2_PIN|LED3_PIN|LED4_PIN ;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIO_LED, &GPIO_InitStructure);
  
  GPIO_SetBits(GPIO_LED, LED1_PIN|LED2_PIN|LED3_PIN|LED4_PIN);
       
  /* USARTx configured as follow:
        - BaudRate = 115200 baud  
        - Word Length = 8 Bits
        - One Stop Bit
        - No parity
        - Hardware flow control disabled (RTS and CTS signals)
        - Receive and transmit enabled
  */
  USART_InitStructure.USART_BaudRate = 115200;
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_No;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;

  STM_EVAL_COMInit(COM1, &USART_InitStructure);

  /* Output a message on Hyperterminal using printf function */
  printf("\n\r---------------------------------------------\n ");
  printf("\n\r\n ");
  printf("\n\r\n");
  /* Output a message on Hyperterminal using printf function */
  printf("\n\rUSART Printf Example: retarget the C library printf function to the USART\n\r");
  //printf("\r\n\n\n WWW.ARMJISHU.COM  %s configured....", EVAL_COM1_STR);
  printf("\n\r ############ WWW.ARMJISHU.COM! ############ ("__DATE__ " - " __TIME__ ")");

  printf("\r\n");
  printf("  _____ _______ __  __ ____ ___  ______ __  ___\r\n");
  printf(" / ____|__   __|  \\/  |___ \\__ \\|  ____/_ |/ _ \\\r\n");
  printf("| (___    | |  | \\  / | __) | ) | |__   | | | | |_  __\r\n");
  printf(" \\___ \\   | |  | |\\/| ||__ < / /|  __|  | | | | \\ \\/ /\r\n");
  printf(" ____) |  | |  | |  | |___) / /_| |     | | |_| |>  <\r\n");
  printf("|_____/   |_|  |_|  |_|____/____|_|     |_|\\___//_/\\_\\\r\n");
  printf("\r\n");

  printf("\n\r WWW.ARMJISHU.COM use __STM32F10X_STDPERIPH_VERSION %d.%d.%d\n\r",
			__STM32F10X_STDPERIPH_VERSION_MAIN,
			__STM32F10X_STDPERIPH_VERSION_SUB1,
			__STM32F10X_STDPERIPH_VERSION_SUB2);
  printf("\n\r Flash size %dK byte \t www.armjishu.com\n\r",  *(__IO uint16_t*)(0x1FFFF7E0));
  ADS7843_Init();
  
  ili9320_Initializtion();

  ili9320_Clear(Blue);  

  x = 0;
  y = 0;
  str = c;
  charColor = Black;
  bkColor = White;
  for (i=0;i<len;i++)
  {
    ili9320_PutChar((x+8*i),y,*str++,charColor,bkColor);
  }
  Delay_ARMJISHU(10000);
  //Delay_ARMJISHU(4000000);

  charColor = Yellow;
  bkColor = Red;
  
  /* Main loop */
  while (1) 
  {
      DrawPicture_Center((u16 *)picture);
      ili9320_PutStr_16x24_Center(20, c, len,charColor, bkColor);
      ili9320_PutStr_16x24_Center(200, c2, c2len,charColor, bkColor);
      Delay_ARMJISHU(10000000);
    
      ili9320_ColorScreen();
      ili9320_PutStr_16x24_Center(108, c, len,White, HyalineBackColor);
      Delay_ARMJISHU(10000000);

      ili9320_GreyScreen();
      ili9320_PutStr_16x24_Center(108, c, len,White, HyalineBackColor);
      Delay_ARMJISHU(4000000); 
#if 0
	  GPIO_ResetBits(GPIO_LED, LED1_PIN);
	  Delay(0x3FFFFF);
  	  GPIO_SetBits(GPIO_LED, LED1_PIN);
	  Delay(0x3FFFFF);
#endif
  }

}

/**
  * @brief  Retargets the C library printf function to the USART.
  * @param  None
  * @retval None
  */
PUTCHAR_PROTOTYPE
{
  /* Place your implementation of fputc here */
  /* e.g. write a character to the USART */
  USART_SendData(EVAL_COM1, (uint8_t) ch);

  /* Loop until the end of transmission */
  while (USART_GetFlagStatus(EVAL_COM1, USART_FLAG_TC) == RESET)
  {
  }

  return ch;
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */ 

/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2010 STMicroelectronics *****END OF FILE****/
